/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2007 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp07nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp07nid ;

DATA library.&dataset ;
INFILE datafile LRECL=2357;
INPUT
   DISGORGE  1-3            BUSTEXT $ 4-62           OWNSTEXT $ 63-75      
   FINSTXT $ 76-112         FINDOTXT $ 113           OFENTXT1 $ 114-141    
   OFENTXT2 $ 142           OFENTXT3 $ 143           PRMONTXT $ 144-193    
   ORDERTXT $ 194-292       TYPEOTTX $ 293-491       CPIDN  492-498        
   PSR  499                 JANDC  500               PLEA  501-502         
   REASONS  503             INDICT  504              SENTRANS  505         
   WRKSHT  506              INCORPYR  507-510        INCORLOC  511         
   ORGTYPE  512             BUSCLAS  513-516         FTEMNUM  517-522      
   FTEMSIGN  523            SELFREP  524             HSMISCND  525         
   PRCRIME  526             PRCIVIL  527             OWNSTRCT  528         
   FINSTDS  529             FINSTDO  530             OFFENSE1  531-532     
   OFFENSE2  533-534        OFFENSE3  535-536        PRIMOFF  537-538      
   NOCOUNTS  539-540        SOURCES  541             OFFLVL  542-543       
   DETBFINE  544            TOLERNCE  545            HISTORY  546          
   VIOLATE  547             OBSTRUCT  548            COMPLY  549           
   ACCEPT  550-551          CCULPSCO  552-553        FCULPSCO  554-555     
   MINFINML  556-559        MAXFINML  560-562        DISPOSIT  563         
   PROBATN  564-565         COFI  566                PROBMON  567          
   ORDERCE  568             TYPEOTHS  569-570        CRIMPURP  571         
   CANTPAY  572             ADJOFL1  573-574         ADJOFL2  575-576      
   ADJOFLHI  577-578        ADJ_B1  579-580          ADJ_B2  581           
   ADJ_BHI  582-583         ADJ_C1  584-585          ADJ_C2  586           
   ADJ_CHI  587-588         ADJ_D1  589              ADJ_D2  590           
   ADJ_DHI  591             ADJ_E1  592              ADJ_E2  593           
   ADJ_EHI  594             ADJ_F1  595              ADJ_F2  596           
   ADJ_FHI  597             ADJ_G1  598              ADJ_G2  599           
   ADJ_GHI  600             ADJ_H1  601              ADJ_H2  602           
   ADJ_HHI  603             ADJ_I1  604              ADJ_I2  605           
   ADJ_IHI  606             ADJ_J1  607              ADJ_J2  608           
   ADJ_JHI  609             ADJ_K1  610              ADJ_K2  611           
   ADJ_KHI  612             ADJ_L1  613              ADJ_L2  614           
   ADJ_LHI  615             ADJ_M1  616              ADJ_M2  617           
   ADJ_MHI  618             ADJ_N1  619              ADJ_N2  620           
   ADJ_NHI  621             ADJ_O1  622              ADJ_O2  623           
   ADJ_OHI  624             ADJ_P1  625              ADJ_P2  626           
   ADJ_PHI  627             BASADJ1  628             BASADJ2  629          
   BASADJHI  630            BASE1  631-632           BASE2  633            
   BASEHI  634-635          ADJOFR1  636-637         ADJOFR2  638-639      
   ADJOFRHI  640-641        ADJR_B1  642-643         ADJR_B2  644          
   ADJR_BHI  645-646        ADJR_C1  647             ADJR_C2  648          
   ADJR_CHI  649            ADJR_D1  650             ADJR_D2  651          
   ADJR_DHI  652            ADJR_E1  653             ADJR_E2  654          
   ADJR_EHI  655            ADJR_F1  656             ADJR_F2  657          
   ADJR_FHI  658            ADJR_G1  659             ADJR_G2  660          
   ADJR_GHI  661            ADJR_H1  662             ADJR_H2  663          
   ADJR_HHI  664            ADJR_I1  665             ADJR_I2  666          
   ADJR_IHI  667            ADJR_J1  668             ADJR_J2  669          
   ADJR_JHI  670            ADJR_K1  671             ADJR_K2  672          
   ADJR_KHI  673            ADJR_L1  674             ADJR_L2  675          
   ADJR_LHI  676            ADJR_M1  677             ADJR_M2  678          
   ADJR_MHI  679            ADJR_N1  680             ADJR_N2  681          
   ADJR_NHI  682            ADJR_O1  683             ADJR_O2  684          
   ADJR_OHI  685            ADJR_P1  686             ADJR_P2  687          
   ADJR_PHI  688            BASADR1  689             BASADR2  690          
   BASADRHI  691            BASER1  692-693          BASER2  694           
   BASERHI  695-696         ADJOFS1  697-698         ADJOFS2  699          
   ADJOFSHI  700-701        ADJS_B1  702-703         ADJS_B2  704          
   ADJS_BHI  705-706        ADJS_C1  707-708         ADJS_C2  709          
   ADJS_CHI  710-711        ADJS_D1  712             ADJS_D2  713          
   ADJS_DHI  714            ADJS_E1  715             ADJS_E2  716          
   ADJS_EHI  717            ADJS_F1  718             ADJS_F2  719          
   ADJS_FHI  720            ADJS_G1  721             ADJS_G2  722          
   ADJS_GHI  723            ADJS_H1  724             ADJS_H2  725          
   ADJS_HHI  726            ADJS_I1  727             ADJS_I2  728          
   ADJS_IHI  729            ADJS_J1  730             ADJS_J2  731          
   ADJS_JHI  732            ADJS_K1  733             ADJS_K2  734          
   ADJS_KHI  735            ADJS_L1  736             ADJS_L2  737          
   ADJS_LHI  738            ADJS_M1  739             ADJS_M2  740          
   ADJS_MHI  741            ADJS_N1  742             ADJS_N2  743          
   ADJS_NHI  744            ADJS_O1  745             ADJS_O2  746          
   ADJS_OHI  747            ADJS_P1  748             ADJS_P2  749          
   ADJS_PHI  750            BASADS1  751             BASADS2  752          
   BASADSHI  753            BASES1  754-755          BASES2  756           
   BASESHI  757-758         ADJOFC1  759-760         ADJOFC2  761          
   ADJOFCHI  762-763        ADJC_B1  764-765         ADJC_B2  766          
   ADJC_BHI  767-768        ADJC_C1  769             ADJC_C2  770          
   ADJC_CHI  771            ADJC_D1  772             ADJC_D2  773          
   ADJC_DHI  774            ADJC_E1  775             ADJC_E2  776          
   ADJC_EHI  777            ADJC_F1  778             ADJC_F2  779          
   ADJC_FHI  780            ADJC_G1  781             ADJC_G2  782          
   ADJC_GHI  783            ADJC_H1  784             ADJC_H2  785          
   ADJC_HHI  786            ADJC_I1  787             ADJC_I2  788          
   ADJC_IHI  789            ADJC_J1  790             ADJC_J2  791          
   ADJC_JHI  792            ADJC_K1  793             ADJC_K2  794          
   ADJC_KHI  795            ADJC_L1  796             ADJC_L2  797          
   ADJC_LHI  798            ADJC_M1  799             ADJC_M2  800          
   ADJC_MHI  801            ADJC_N1  802             ADJC_N2  803          
   ADJC_NHI  804            ADJC_O1  805             ADJC_O2  806          
   ADJC_OHI  807            ADJC_P1  808             ADJC_P2  809          
   ADJC_PHI  810            BASADC1  811             BASADC2  812          
   BASADCHI  813            BASEC1  814              BASEC2  815           
   BASECHI  816             ADJL_B1 $ 817            ADJL_B2 $ 818         
   ADJL_BHI $ 819           ADJL_C1 $ 820-821        ADJL_C2 $ 822         
   ADJL_CHI $ 823-824       ADJL_D1 $ 825            ADJL_D2 $ 826         
   ADJL_DHI $ 827           ADJL_E1 $ 828            ADJL_E2 $ 829         
   ADJL_EHI $ 830           ADJL_F1 $ 831            ADJL_F2 $ 832         
   ADJL_FHI $ 833           ADJL_G1 $ 834            ADJL_G2 $ 835         
   ADJL_GHI $ 836           ADJL_H1 $ 837            ADJL_H2 $ 838         
   ADJL_HHI $ 839           ADJL_I1 $ 840            ADJL_I2 $ 841         
   ADJL_IHI $ 842           ADJL_J1 $ 843            ADJL_J2 $ 844         
   ADJL_JHI $ 845           ADJL_K1 $ 846-847        ADJL_K2 $ 848         
   ADJL_KHI $ 849-850       ADJL_L1 $ 851            ADJL_L2 $ 852         
   ADJL_LHI $ 853           ADJL_M1 $ 854            ADJL_M2 $ 855         
   ADJL_MHI $ 856           ADJL_N1 $ 857            ADJL_N2 $ 858         
   ADJL_NHI $ 859           ADJL_O1 $ 860            ADJL_O2 $ 861         
   ADJL_OHI $ 862           ADJL_P1 $ 863            ADJL_P2 $ 864         
   ADJL_PHI $ 865           BASEL1 $ 866             BASEL2 $ 867          
   BASELHI $ 868            ADRL_B1 $ 869            ADRL_B2 $ 870         
   ADRL_BHI $ 871           ADRL_C1 $ 872-873        ADRL_C2 $ 874         
   ADRL_CHI $ 875-876       ADRL_D1 $ 877            ADRL_D2 $ 878         
   ADRL_DHI $ 879           ADRL_E1 $ 880            ADRL_E2 $ 881         
   ADRL_EHI $ 882           ADRL_F1 $ 883            ADRL_F2 $ 884         
   ADRL_FHI $ 885           ADRL_G1 $ 886            ADRL_G2 $ 887         
   ADRL_GHI $ 888           ADRL_H1 $ 889            ADRL_H2 $ 890         
   ADRL_HHI $ 891           ADRL_I1 $ 892            ADRL_I2 $ 893         
   ADRL_IHI $ 894           ADRL_J1 $ 895            ADRL_J2 $ 896         
   ADRL_JHI $ 897           ADRL_K1 $ 898            ADRL_K2 $ 899         
   ADRL_KHI $ 900           ADRL_L1 $ 901            ADRL_L2 $ 902         
   ADRL_LHI $ 903           ADRL_M1 $ 904            ADRL_M2 $ 905         
   ADRL_MHI $ 906           ADRL_N1 $ 907            ADRL_N2 $ 908         
   ADRL_NHI $ 909           ADRL_O1 $ 910            ADRL_O2 $ 911         
   ADRL_OHI $ 912           ADRL_P1 $ 913            ADRL_P2 $ 914         
   ADRL_PHI $ 915           BASERL1 $ 916            BASERL2 $ 917         
   BASERLHI $ 918           ADSL_B1 $ 919            ADSL_B2 $ 920         
   ADSL_BHI $ 921           ADSL_C1 $ 922-923        ADSL_C2 $ 924         
   ADSL_CHI $ 925-926       ADSL_D1 $ 927            ADSL_D2 $ 928         
   ADSL_DHI $ 929           ADSL_E1 $ 930            ADSL_E2 $ 931         
   ADSL_EHI $ 932           ADSL_F1 $ 933            ADSL_F2 $ 934         
   ADSL_FHI $ 935           ADSL_G1 $ 936            ADSL_G2 $ 937         
   ADSL_GHI $ 938           ADSL_H1 $ 939            ADSL_H2 $ 940         
   ADSL_HHI $ 941           ADSL_I1 $ 942            ADSL_I2 $ 943         
   ADSL_IHI $ 944           ADSL_J1 $ 945            ADSL_J2 $ 946         
   ADSL_JHI $ 947           ADSL_K1 $ 948-949        ADSL_K2 $ 950         
   ADSL_KHI $ 951-952       ADSL_L1 $ 953            ADSL_L2 $ 954         
   ADSL_LHI $ 955           ADSL_M1 $ 956            ADSL_M2 $ 957         
   ADSL_MHI $ 958           ADSL_N1 $ 959            ADSL_N2 $ 960         
   ADSL_NHI $ 961           ADSL_O1 $ 962            ADSL_O2 $ 963         
   ADSL_OHI $ 964           ADSL_P1 $ 965            ADSL_P2 $ 966         
   ADSL_PHI $ 967           BASESL1 $ 968            BASESL2 $ 969         
   BASESLHI $ 970           ADCL_B1 $ 971            ADCL_B2 $ 972         
   ADCL_BHI $ 973           ADCL_C1 $ 974            ADCL_C2 $ 975         
   ADCL_CHI $ 976           ADCL_D1 $ 977            ADCL_D2 $ 978         
   ADCL_DHI $ 979           ADCL_E1 $ 980            ADCL_E2 $ 981         
   ADCL_EHI $ 982           ADCL_F1 $ 983            ADCL_F2 $ 984         
   ADCL_FHI $ 985           ADCL_G1 $ 986            ADCL_G2 $ 987         
   ADCL_GHI $ 988           ADCL_H1 $ 989            ADCL_H2 $ 990         
   ADCL_HHI $ 991           ADCL_I1 $ 992            ADCL_I2 $ 993         
   ADCL_IHI $ 994           ADCL_J1 $ 995            ADCL_J2 $ 996         
   ADCL_JHI $ 997           ADCL_K1 $ 998            ADCL_K2 $ 999         
   ADCL_KHI $ 1000          ADCL_L1 $ 1001           ADCL_L2 $ 1002        
   ADCL_LHI $ 1003          ADCL_M1 $ 1004           ADCL_M2 $ 1005        
   ADCL_MHI $ 1006          ADCL_N1 $ 1007           ADCL_N2 $ 1008        
   ADCL_NHI $ 1009          ADCL_O1 $ 1010           ADCL_O2 $ 1011        
   ADCL_OHI $ 1012          ADCL_P1 $ 1013           ADCL_P2 $ 1014        
   ADCL_PHI $ 1015          BASECL1 $ 1016           BASECL2 $ 1017-1019   
   BASECLHI $ 1020          GDLINE1 $ 1021-1025      GDLINE2 $ 1026-1030   
   GDSTAT1 $ 1031-1035      GDSTAT2 $ 1036-1040      GDREF1 $ 1041-1045    
   GDREF2 $ 1046-1050       GDCROS1 $ 1051-1055      GDCROS2 $ 1056        
   NOCOMP  1057             GDLINEHI $ 1058-1062     GDSTATHI $ 1063-1067  
   GDREFHI $ 1068-1072      GDCROSHI $ 1073-1077     SMIN1  1078-1085      
   SMIN2  1086-1093         SMIN3  1094-1101         SMIN4  1102-1109      
   SMIN5  1110-1117         SMIN6  1118-1124         SMIN7  1125-1131      
   SMIN8  1132-1138         SMIN9  1139              SMIN10  1140          
   SMIN11  1141             SMIN12  1142             SMIN13  1143          
   SMIN14  1144             SMIN15  1145             SMIN16  1146          
   SMIN17  1147             SMIN18  1148             SMIN19  1149          
   SMIN20  1150             SMIN21  1151             SMIN22  1152          
   SMIN23  1153             SMIN24  1154             SMIN25  1155          
   SMIN26  1156             SMIN27  1157             SMIN28  1158          
   SMIN29  1159             SMIN30  1160             SMIN31  1161          
   SMAX1  1162-1170         SMAX2  1171-1179         SMAX3  1180-1188      
   SMAX4  1189-1197         SMAX5  1198-1206         SMAX6  1207-1213      
   SMAX7  1214-1220         SMAX8  1221-1227         SMAX9  1228-1234      
   SMAX10  1235-1241        SMAX11  1242-1248        SMAX12  1249-1255     
   SMAX13  1256-1262        SMAX14  1263-1269        SMAX15  1270-1276     
   SMAX16  1277-1283        SMAX17  1284-1290        SMAX18  1291-1297     
   SMAX19  1298-1304        SMAX20  1305-1311        SMAX21  1312-1318     
   SMAX22  1319-1325        SMAX23  1326-1332        SMAX24  1333-1339     
   SMAX25  1340-1346        SMAX26  1347-1353        SMAX27  1354-1359     
   SMAX28  1360-1365        SMAX29  1366-1371        SMAX30  1372-1377     
   SMAX31  1378-1383        STA1_1 $ 1384-1394       STA1_2 $ 1395-1404    
   STA1_3 $ 1405-1414       STA1_4 $ 1415-1424       STA1_5 $ 1425-1434    
   STA1_6 $ 1435-1443       STA1_7 $ 1444-1452       STA1_8 $ 1453-1461    
   STA1_9 $ 1462-1471       STA1_10 $ 1472-1481      STA1_11 $ 1482-1488   
   STA1_12 $ 1489-1495      STA1_13 $ 1496-1502      STA1_14 $ 1503-1509   
   STA1_15 $ 1510-1516      STA1_16 $ 1517-1523      STA1_17 $ 1524-1530   
   STA1_18 $ 1531-1537      STA1_19 $ 1538-1544      STA1_20 $ 1545-1551   
   STA1_21 $ 1552-1558      STA1_22 $ 1559-1565      STA1_23 $ 1566-1572   
   STA1_24 $ 1573-1579      STA1_25 $ 1580-1585      STA1_26 $ 1586-1591   
   STA1_27 $ 1592-1594      STA1_28 $ 1595-1597      STA1_29 $ 1598-1600   
   STA1_30 $ 1601-1603      STA1_31 $ 1604-1606      STA2_1 $ 1607-1617    
   STA2_2 $ 1618-1627       STA2_3 $ 1628-1637       STA2_4 $ 1638-1646    
   STA2_5 $ 1647-1655       STA2_6 $ 1656-1663       STA2_7 $ 1664-1671    
   STA2_8 $ 1672-1679       STA2_9 $ 1680-1689       STA2_10 $ 1690-1699   
   STA2_11 $ 1700-1707      STA2_12 $ 1708-1713      STA2_13 $ 1714-1719   
   STA2_14 $ 1720-1726      STA2_15 $ 1727-1733      STA2_16 $ 1734-1740   
   STA2_17 $ 1741-1746      STA2_18 $ 1747-1752      STA2_19 $ 1753-1758   
   STA2_20 $ 1759-1764      STA2_21 $ 1765-1771      STA2_22 $ 1772-1777   
   STA2_23 $ 1778-1780      STA2_24 $ 1781-1790      STA2_25 $ 1791-1800   
   STA2_26 $ 1801-1810      STA2_27 $ 1811-1820      STA2_28 $ 1821-1830   
   STA2_29 $ 1831-1840      STA2_30 $ 1841-1850      STA2_31 $ 1851-1860   
   STA3_1 $ 1861-1870       STA3_2 $ 1871-1878       STA3_3 $ 1879-1887    
   STA3_4 $ 1888-1895       STA3_5 $ 1896-1902       STA3_6 $ 1903-1909    
   STA3_7 $ 1910-1915       STA3_8 $ 1916-1921       STA3_9 $ 1922-1929    
   STA3_10 $ 1930-1934      STA3_11 $ 1935-1941      STA3_12 $ 1942-1947   
   STA3_13 $ 1948-1953      STA3_14 $ 1954-1960      STA3_15 $ 1961-1966   
   STA3_16 $ 1967-1972      STA3_17 $ 1973-1979      STA3_18 $ 1980-1986   
   STA3_19 $ 1987-1993      STA3_20 $ 1994-2000      STA3_21 $ 2001-2006   
   STA3_22 $ 2007-2013      STA3_23 $ 2014-2020      STA3_24 $ 2021-2027   
   STA3_25 $ 2028           STA3_26 $ 2029           STA3_27 $ 2030        
   STA3_28 $ 2031           STA3_29 $ 2032           STA3_30 $ 2033        
   STA3_31 $ 2034           NWSTAT1 $ 2035-2045      NWSTAT2 $ 2046-2056   
   NWSTAT3 $ 2057-2066      NWSTAT4 $ 2067-2076      NWSTAT5 $ 2077-2086   
   NWSTAT6 $ 2087-2094      NWSTAT7 $ 2095-2103      NWSTAT8 $ 2104-2110   
   NWSTAT9 $ 2111-2117      NWSTAT10 $ 2118-2127     NWSTAT11 $ 2128-2137  
   NWSTAT12 $ 2138-2142     NWSTAT13 $ 2143-2148     NWSTAT14 $ 2149-2155  
   NWSTAT15 $ 2156-2161     NWSTAT16 $ 2162-2168     NOUSTAT  2169-2170    
   AMENDYR  2171-2174       BASEFINE  2175-2183      CH2APP  2184          
   CH8FINGD  2185           CMSRVORD  2186           COMPLYPR  2187        
   COSTASSM  2188           FINOFFST  2189-2195      FORFEITR  2196-2205   
   GLFINMAX  2206-2214      GLFINMIN  2215-2223      REMEDORD  2224-2226   
   VICTNOTE  2227           BOOKERCD  2228-2229      QUARTER  2230         
   RETEXT1 $ 2231-2257      RETEXT2 $ 2258-2283      RETEXT3 $ 2284        
   RETEXT4 $ 2285           RETEXT5 $ 2286           RETEXT6 $ 2287        
   RETEXT7 $ 2288           RETEXT8 $ 2289           RETEXT9 $ 2290        
   RETEXT10 $ 2291          REAS1  2292-2294         REAS2  2295-2297      
   REAS3  2298              REAS4  2299-2301         REAS5  2302-2304      
   REAS6  2305-2307         REAS7  2308              REAS8  2309           
   REAS9  2310              REAS10  2311             INPLEA1  2312         
   INPLEA2  2313            INPLEA3  2314            INPLEA4  2315         
   INPLEA5  2316            INPLEA6  2317            INPLEA7  2318         
   INPLEA8  2319            INPLEA9  2320            INPLEA10  2321        
   INPLEA11  2322           INPLEA12  2323           INNOPL1  2324         
   INNOPL2  2325            INNOPL3  2326            INNOPL4  2327         
   INNOPL5  2328            INNOPL6  2329            INNOPL7  2330         
   INNOPL8  2331            INNOPL9  2332            INNOPL10  2333        
   INNOPL11  2334           INNOPL12  2335           SENTYR  2336-2339     
   BOOKER2  2340            BOOKER3  2341            NEWCNVTN  2342        
   RESTCAT  2343            FINECAT  2344            SUSFNCAT  2345        
   LCAT1  2346              LCAT2  2347              LCATHI  2348          
   LCATS1  2349             LCATS2  2350             LCATSHI  2351         
   LCATR1  2352             LCATR2  2353             LCATRHI  2354         
   LCATC1  2355             LCATC2  2356             LCATCHI  2357         
 ;                       

LENGTH
   DISGORGE 4               CPIDN 6                  PSR 3                 
   JANDC 3                  PLEA 3                   REASONS 3             
   INDICT 3                 SENTRANS 3               WRKSHT 3              
   INCORPYR 4               INCORLOC 3               ORGTYPE 3             
   BUSCLAS 4                FTEMNUM 6                FTEMSIGN 3            
   SELFREP 3                HSMISCND 3               PRCRIME 3             
   PRCIVIL 3                OWNSTRCT 3               FINSTDS 3             
   FINSTDO 3                OFFENSE1 3               OFFENSE2 3            
   OFFENSE3 3               PRIMOFF 3                NOCOUNTS 3            
   SOURCES 3                OFFLVL 3                 DETBFINE 3            
   TOLERNCE 3               HISTORY 3                VIOLATE 3             
   OBSTRUCT 3               COMPLY 3                 ACCEPT 3              
   CCULPSCO 3               FCULPSCO 3               DISPOSIT 3            
   PROBATN 3                COFI 3                   PROBMON 3             
   ORDERCE 3                TYPEOTHS 3               CRIMPURP 3            
   CANTPAY 3                ADJOFL1 3                ADJOFL2 3             
   ADJOFLHI 3               ADJ_B1 3                 ADJ_B2 3              
   ADJ_BHI 3                ADJ_C1 3                 ADJ_C2 3              
   ADJ_CHI 3                ADJ_D1 3                 ADJ_D2 3              
   ADJ_DHI 3                ADJ_E1 3                 ADJ_E2 3              
   ADJ_EHI 3                ADJ_F1 3                 ADJ_F2 3              
   ADJ_FHI 3                ADJ_G1 3                 ADJ_G2 3              
   ADJ_GHI 3                ADJ_H1 3                 ADJ_H2 3              
   ADJ_HHI 3                ADJ_I1 3                 ADJ_I2 3              
   ADJ_IHI 3                ADJ_J1 3                 ADJ_J2 3              
   ADJ_JHI 3                ADJ_K1 3                 ADJ_K2 3              
   ADJ_KHI 3                ADJ_L1 3                 ADJ_L2 3              
   ADJ_LHI 3                ADJ_M1 3                 ADJ_M2 3              
   ADJ_MHI 3                ADJ_N1 3                 ADJ_N2 3              
   ADJ_NHI 3                ADJ_O1 3                 ADJ_O2 3              
   ADJ_OHI 3                ADJ_P1 3                 ADJ_P2 3              
   ADJ_PHI 3                BASADJ1 3                BASADJ2 3             
   BASADJHI 3               BASE1 3                  BASE2 3               
   BASEHI 3                 ADJOFR1 3                ADJOFR2 3             
   ADJOFRHI 3               ADJR_B1 3                ADJR_B2 3             
   ADJR_BHI 3               ADJR_C1 3                ADJR_C2 3             
   ADJR_CHI 3               ADJR_D1 3                ADJR_D2 3             
   ADJR_DHI 3               ADJR_E1 3                ADJR_E2 3             
   ADJR_EHI 3               ADJR_F1 3                ADJR_F2 3             
   ADJR_FHI 3               ADJR_G1 3                ADJR_G2 3             
   ADJR_GHI 3               ADJR_H1 3                ADJR_H2 3             
   ADJR_HHI 3               ADJR_I1 3                ADJR_I2 3             
   ADJR_IHI 3               ADJR_J1 3                ADJR_J2 3             
   ADJR_JHI 3               ADJR_K1 3                ADJR_K2 3             
   ADJR_KHI 3               ADJR_L1 3                ADJR_L2 3             
   ADJR_LHI 3               ADJR_M1 3                ADJR_M2 3             
   ADJR_MHI 3               ADJR_N1 3                ADJR_N2 3             
   ADJR_NHI 3               ADJR_O1 3                ADJR_O2 3             
   ADJR_OHI 3               ADJR_P1 3                ADJR_P2 3             
   ADJR_PHI 3               BASADR1 3                BASADR2 3             
   BASADRHI 3               BASER1 3                 BASER2 3              
   BASERHI 3                ADJOFS1 3                ADJOFS2 3             
   ADJOFSHI 3               ADJS_B1 3                ADJS_B2 3             
   ADJS_BHI 3               ADJS_C1 3                ADJS_C2 3             
   ADJS_CHI 3               ADJS_D1 3                ADJS_D2 3             
   ADJS_DHI 3               ADJS_E1 3                ADJS_E2 3             
   ADJS_EHI 3               ADJS_F1 3                ADJS_F2 3             
   ADJS_FHI 3               ADJS_G1 3                ADJS_G2 3             
   ADJS_GHI 3               ADJS_H1 3                ADJS_H2 3             
   ADJS_HHI 3               ADJS_I1 3                ADJS_I2 3             
   ADJS_IHI 3               ADJS_J1 3                ADJS_J2 3             
   ADJS_JHI 3               ADJS_K1 3                ADJS_K2 3             
   ADJS_KHI 3               ADJS_L1 3                ADJS_L2 3             
   ADJS_LHI 3               ADJS_M1 3                ADJS_M2 3             
   ADJS_MHI 3               ADJS_N1 3                ADJS_N2 3             
   ADJS_NHI 3               ADJS_O1 3                ADJS_O2 3             
   ADJS_OHI 3               ADJS_P1 3                ADJS_P2 3             
   ADJS_PHI 3               BASADS1 3                BASADS2 3             
   BASADSHI 3               BASES1 3                 BASES2 3              
   BASESHI 3                ADJOFC1 3                ADJOFC2 3             
   ADJOFCHI 3               ADJC_B1 3                ADJC_B2 3             
   ADJC_BHI 3               ADJC_C1 3                ADJC_C2 3             
   ADJC_CHI 3               ADJC_D1 3                ADJC_D2 3             
   ADJC_DHI 3               ADJC_E1 3                ADJC_E2 3             
   ADJC_EHI 3               ADJC_F1 3                ADJC_F2 3             
   ADJC_FHI 3               ADJC_G1 3                ADJC_G2 3             
   ADJC_GHI 3               ADJC_H1 3                ADJC_H2 3             
   ADJC_HHI 3               ADJC_I1 3                ADJC_I2 3             
   ADJC_IHI 3               ADJC_J1 3                ADJC_J2 3             
   ADJC_JHI 3               ADJC_K1 3                ADJC_K2 3             
   ADJC_KHI 3               ADJC_L1 3                ADJC_L2 3             
   ADJC_LHI 3               ADJC_M1 3                ADJC_M2 3             
   ADJC_MHI 3               ADJC_N1 3                ADJC_N2 3             
   ADJC_NHI 3               ADJC_O1 3                ADJC_O2 3             
   ADJC_OHI 3               ADJC_P1 3                ADJC_P2 3             
   ADJC_PHI 3               BASADC1 3                BASADC2 3             
   BASADCHI 3               BASEC1 3                 BASEC2 3              
   BASECHI 3                NOCOMP 3                 SMIN1 6               
   SMIN2 6                  SMIN3 6                  SMIN4 6               
   SMIN5 6                  SMIN6 6                  SMIN7 6               
   SMIN8 6                  SMIN9 3                  SMIN10 3              
   SMIN11 3                 SMIN12 3                 SMIN13 3              
   SMIN14 3                 SMIN15 3                 SMIN16 3              
   SMIN17 3                 SMIN18 3                 SMIN19 3              
   SMIN20 3                 SMIN21 3                 SMIN22 3              
   SMIN23 3                 SMIN24 3                 SMIN25 3              
   SMIN26 3                 SMIN27 3                 SMIN28 3              
   SMIN29 3                 SMIN30 3                 SMIN31 3              
   SMAX1 6                  SMAX2 6                  SMAX3 6               
   SMAX4 6                  SMAX5 6                  SMAX6 6               
   SMAX7 6                  SMAX8 6                  SMAX9 6               
   SMAX10 6                 SMAX11 6                 SMAX12 6              
   SMAX13 6                 SMAX14 6                 SMAX15 6              
   SMAX16 6                 SMAX17 6                 SMAX18 6              
   SMAX19 6                 SMAX20 6                 SMAX21 6              
   SMAX22 6                 SMAX23 6                 SMAX24 6              
   SMAX25 6                 SMAX26 6                 SMAX27 6              
   SMAX28 6                 SMAX29 6                 SMAX30 6              
   SMAX31 6                 NOUSTAT 3                AMENDYR 4             
   BASEFINE 6               CH2APP 3                 CH8FINGD 3            
   CMSRVORD 3               COMPLYPR 3               COSTASSM 3            
   FINOFFST 6               GLFINMAX 6               GLFINMIN 6            
   REMEDORD 3               VICTNOTE 3               BOOKERCD 3            
   QUARTER 3                REAS1 4                  REAS2 4               
   REAS3 3                  REAS4 4                  REAS5 4               
   REAS6 4                  REAS7 3                  REAS8 3               
   REAS9 3                  REAS10 3                 INPLEA1 3             
   INPLEA2 3                INPLEA3 3                INPLEA4 3             
   INPLEA5 3                INPLEA6 3                INPLEA7 3             
   INPLEA8 3                INPLEA9 3                INPLEA10 3            
   INPLEA11 3               INPLEA12 3               INNOPL1 3             
   INNOPL2 3                INNOPL3 3                INNOPL4 3             
   INNOPL5 3                INNOPL6 3                INNOPL7 3             
   INNOPL8 3                INNOPL9 3                INNOPL10 3            
   INNOPL11 3               INNOPL12 3               SENTYR 4              
   BOOKER2 3                BOOKER3 3                NEWCNVTN 3            
   RESTCAT 3                FINECAT 3                SUSFNCAT 3            
   LCAT1 3                  LCAT2 3                  LCATHI 3              
   LCATS1 3                 LCATS2 3                 LCATSHI 3             
   LCATR1 3                 LCATR2 3                 LCATRHI 3             
   LCATC1 3                 LCATC2 3                 LCATCHI 3 ;

         

RUN ;
